package com.zehong.system.mapper;

import java.util.List;
import java.util.Map;

import com.zehong.system.domain.TDevLifeCycle;

/**
 * 【请填写功能名称】Mapper接口
 * 
 * @author zehong
 * @date 2023-12-12
 */
public interface TDevLifeCycleMapper 
{
    /**
     * 查询【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 【请填写功能名称】
     */
    public TDevLifeCycle selectTDevLifeCycleById(Long id);

    /**
     * 查询【请填写功能名称】列表
     * 
     * @param tDevLifeCycle 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
    public List<TDevLifeCycle> selectTDevLifeCycleList(TDevLifeCycle tDevLifeCycle);
    public List<TDevLifeCycle> selectTDevLifeCycleListByParam(TDevLifeCycle tDevLifeCycle);

    /**
     * 新增【请填写功能名称】
     * 
     * @param tDevLifeCycle 【请填写功能名称】
     * @return 结果
     */
    public int insertTDevLifeCycle(TDevLifeCycle tDevLifeCycle);

    /**
     * 修改【请填写功能名称】
     * 
     * @param tDevLifeCycle 【请填写功能名称】
     * @return 结果
     */
    public int updateTDevLifeCycle(TDevLifeCycle tDevLifeCycle);

    /**
     * 删除【请填写功能名称】
     * 
     * @param id 【请填写功能名称】ID
     * @return 结果
     */
    public int deleteTDevLifeCycleById(Long id);

    /**
     * 批量删除【请填写功能名称】
     * 
     * @param ids 需要删除的数据ID
     * @return 结果
     */
    public int deleteTDevLifeCycleByIds(Long[] ids);

    /**
     * 设备类型统计
     * @return
     */
    List<Map<String,Object>> devLifeStatistic();
}
